@@ -1,4 +1,6 @@
 import netbox.exceptions as exceptions
+
+
 class Dcim(object):
 
     def __init__(self, netbox_con):
@@ -8,14 +10,6 @@ class Dcim(object):
         """Returns the available sites"""
         return self.netbox_con.get('/dcim/sites/', **kwargs)
 
-    def get_site(self, **kwargs):
-        """Get site by filter
-
-        :param kwargs: Filter can be any field.
-        :return: site result
-        """
-        return self.netbox_con.get('/dcim/sites/', **kwargs)
-
     def create_site(self, name, slug, **kwargs):
         """Create new site
 
@@ -34,7 +28,7 @@ class Dcim(object):
         :return: bool True if succesful otherwase delete exception
         """
         try:
-            site_id = self.get_site(name=site_name)[0]['id']
+            site_id = self.get_sites(name=site_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
         return self.netbox_con.delete('/dcim/sites/', site_id)
@@ -47,7 +41,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            site_id = self.get_site(name=site_name)[0]['id']
+            site_id = self.get_sites(name=site_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
         return self.netbox_con.patch('/dcim/sites/', site_id, **kwargs)
@@ -56,14 +50,6 @@ class Dcim(object):
         """Returns the available racks"""
         return self.netbox_con.get('/dcim/racks/', **kwargs)
 
-    def get_rack(self, **kwargs):
-        """Return rack id based on name
-
-        :param kwargs:
-        :return: Rack
-        """
-        return self.netbox_con.get('/dcim/racks/', **kwargs)
-
     def create_rack(self, name, site_name, **kwargs):
         """Create new rack
 
@@ -73,7 +59,7 @@ class Dcim(object):
         :return: bool True if successful otherwise create exception
         """
         try:
-            site_id = self.get_site(name=site_name)[0]['id']
+            site_id = self.get_sites(name=site_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
         required_fields = {"name": name, "site": site_id}
@@ -86,7 +72,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            rack_id = self.get_rack(facility_id=rack_name)[0]['id']
+            rack_id = self.get_racks(facility_id=rack_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('rack: {}'.format(rack_name)) from None
         return self.netbox_con.delete('/dcim/racks/', rack_id)
@@ -99,7 +85,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            rack_id = self.get_rack(facility_id=rack_name)[0]['id']
+            rack_id = self.get_racks(facility_id=rack_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('rack: {}'.format(rack_name)) from None
         return self.netbox_con.patch('/dcim/racks/', rack_id, **kwargs)
@@ -108,14 +94,6 @@ class Dcim(object):
         """Get all devices"""
         return self.netbox_con.get('/dcim/devices/', **kwargs)
 
-    def get_device(self, **kwargs):
-        """Get device by filter
-
-        :param kwargs: Filter can be any field.
-        :return: device result
-        """
-        return self.netbox_con.get('/dcim/devices/', **kwargs)
-
     def get_devices_per_rack(self, rack_name, **kwargs):
         """Get devices which belongs to the given rack
 
@@ -123,7 +101,7 @@ class Dcim(object):
         :return: list of devices otherwise an empty list
         """
         try:
-            rack_id = self.get_rack(facility_id=rack_name)[0]['id']
+            rack_id = self.get_racks(facility_id=rack_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('rack: {}'.format(rack_name)) from None
         return self.netbox_con.get('/dcim/devices', rack_id=rack_id, **kwargs)
@@ -140,19 +118,19 @@ class Dcim(object):
         """
         required_fields = {"name": name}
         try:
-            device_role_id = self.get_device_role(name=device_role)[0]['id']
+            device_role_id = self.get_device_roles(name=device_role)[0]['id']
             required_fields.update({"device_role": device_role_id})
         except IndexError:
             raise exceptions.NotFoundException('device-role: {}'.format(device_role)) from None
 
         try:
-            site_id = self.get_site(name=site_name)[0]['id']
+            site_id = self.get_sites(name=site_name)[0]['id']
             required_fields.update({"site": site_id})
         except IndexError:
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
 
         try:
-            device_type_id = self.get_device_type(model=device_type)[0]['id']
+            device_type_id = self.get_device_types(model=device_type)[0]['id']
             required_fields.update({"device_type": device_type_id})
         except IndexError:
             raise exceptions.NotFoundException('device-type: {}'.format(device_type)) from None
@@ -166,7 +144,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            device_id = self.get_device(name=device_name)[0]['id']
+            device_id = self.get_devices(name=device_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('device: {}'.format(device_name)) from None
         return self.netbox_con.delete('/dcim/devices/', device_id)
@@ -178,21 +156,13 @@ class Dcim(object):
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
-        device_id = self.get_device(name=device_name)[0]['id']
+        device_id = self.get_devices(name=device_name)[0]['id']
         return self.netbox_con.patch('/dcim/devices/', device_id, **kwargs)
 
     def get_device_types(self, **kwargs):
         """Get devices by device type"""
         return self.netbox_con.get('/dcim/device-types/', **kwargs)
 
-    def get_device_type(self, **kwargs):
-        """Get device type by filter
-
-        :param kwargs: Search filter
-        :return: device type
-        """
-        return self.netbox_con.get('/dcim/device-types/', **kwargs)
-
     def create_device_type(self, model, slug, manufacturer, **kwargs):
         """Create device type
 
@@ -213,7 +183,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            device_type_id = self.get_device_type(model=device_type)[0]['id']
+            device_type_id = self.get_device_types(model=device_type)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('device-type: {}'.format(device_type)) from None
         return self.netbox_con.patch('/dcim/device-types/', device_type_id, **kwargs)
@@ -225,7 +195,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            device_type_id = self.get_device_type(model=model_name)[0]['id']
+            device_type_id = self.get_device_types(model=model_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('device-type: {}'.format(model_name)) from None
         return self.netbox_con.delete('/dcim/device-types/', device_type_id)
@@ -234,14 +204,6 @@ class Dcim(object):
         """Return all the device roles"""
         return self.netbox_con.get('/dcim/device-roles/', **kwargs)
 
-    def get_device_role(self, **kwargs):
-        """Get device role by filter
-
-        :param kwargs: Search filter
-        :return: device role
-        """
-        return self.netbox_con.get('/dcim/device-roles/', **kwargs)
-
     def create_device_role(self, name, color, slug, **kwargs):
         """Create device role
 
@@ -257,12 +219,12 @@ class Dcim(object):
     def update_device_role(self, device_role, **kwargs):
         """Update device role
 
-        :param device_type: device-type name to update
+        :param device_role: device-type name to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            device_role_id = self.get_device_type(name=device_role)[0]['id']
+            device_role_id = self.get_device_types(name=device_role)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('device-role: {}'.format(device_role)) from None
         return self.netbox_con.patch('/dcim/device-roles/', device_role_id, **kwargs)
@@ -274,23 +236,15 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            device_role_id = self.get_device_type(name=device_role)[0]['id']
+            device_role_id = self.get_device_types(name=device_role)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('device-role: {}'.format(device_role)) from None
         return self.netbox_con.delete('/dcim/device-roles/', device_role_id)
 
-    def get_manufactures(self, **kwargs):
+    def get_manufacturers(self, **kwargs):
         """Return all manufactures"""
         return self.netbox_con.get('/dcim/manufacturers/', **kwargs)
 
-    def get_manufacturer(self, **kwargs):
-        """Get manufacturer by filter
-
-        :param kwargs: Search filter
-        :return: manufacturer
-        """
-        return self.netbox_con.get('/dcim/manufacturers/', **kwargs)
-
     def create_manufacturer(self, name, slug, **kwargs):
         """Create new manufacturer
 
@@ -310,7 +264,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            manufacturer_id = self.get_manufacturer(name=manufacturer_name)[0]['id']
+            manufacturer_id = self.get_manufacturers(name=manufacturer_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('manufacturer: {}'.format(manufacturer_name)) from None
         return self.netbox_con.patch('/dcim/manufacturer/', manufacturer_id, **kwargs)
@@ -322,7 +276,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            manufacturer_id = self.get_manufacturer(name=manufacturer_name)[0]['id']
+            manufacturer_id = self.get_manufacturers(name=manufacturer_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('manufacturer: {}'.format(manufacturer_name)) from None
         return self.netbox_con.delete('/dcim/manufacturers/', manufacturer_id)
@@ -331,14 +285,6 @@ class Dcim(object):
         """Return all platforms"""
         return self.netbox_con.get('/dcim/platforms', **kwargs)
 
-    def get_platform(self, **kwargs):
-        """Get platform by filter
-
-        :param kwargs: Search filter
-        :return: platform
-        """
-        return self.netbox_con.get('/dcim/platform/', **kwargs)
-
     def create_platform(self, name, slug, **kwargs):
         """Create new platform
 
@@ -353,12 +299,12 @@ class Dcim(object):
     def update_platform(self, platform_name, **kwargs):
         """Update platform
 
-        :param platform: device name to update
+        :param platform_name: device name to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            platform_id = self.get_manufacturer(name=platform_name)[0]['id']
+            platform_id = self.get_manufacturers(name=platform_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.patch('/dcim/platforms/', platform_id, **kwargs)
@@ -370,7 +316,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise DeleteException
         """
         try:
-            platform_id = self.get_manufacturer(name=platform_name)[0]['id']
+            platform_id = self.get_manufacturers(name=platform_name)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.delete('/dcim/platforms/', platform_id)
@@ -379,14 +325,6 @@ class Dcim(object):
         """Return interfaces"""
         return self.netbox_con.get('/dcim/interfaces', **kwargs)
 
-    def get_interface(self, **kwargs):
-        """Get interface by filter
-
-        :param kwargs: Search filter
-        :return: interface
-        """
-        return self.netbox_con.get('/dcim/interfaces/', **kwargs)
-
     def get_interfaces_by_device(self, device_name, **kwargs):
         """Get all interfaces by device
 
@@ -416,7 +354,7 @@ class Dcim(object):
         :return: bool True if successful otherwise raise UpdateException
         """
         try:
-            interface_id = self.get_manufacturer(name=interface)[0]['id']
+            interface_id = self.get_manufacturers(name=interface)[0]['id']
         except IndexError:
             raise exceptions.NotFoundException('interface: {}'.format(interface)) from None
         return self.netbox_con.patch('/dcim/interfaces/', interface_id, **kwargs)
